package	jp.co.sds_corp.hibiya.connector;

import java.util.Map;

import jp.co.sds_corp.hibiya.server.IChecker;
import jp.co.sds_corp.hibiya.server.ICheckerChanger;
import jp.co.sds_corp.util.config.IConfigSavable;
import jp.co.sds_corp.util.config.IConfigurable;

/**
* {@link IChecker}の情報を取得するためのインターフェースです。
*/
public interface IConnector extends IConfigurable, IConfigSavable,
					ICheckerChanger, IConnectionChanger
{
	/**
	* 処理を開始します。
	*/
	public void start();
	/**
	* 処理を開始します。
	*/
	public void stop();

	/**
	* 名前を設定します。
	* @param	var		名前
	*/
	public void setName( String var );
	/**
	* 名前を取得します。
	* @return	名前
	*/
	public String getName();

	/**
	* 状態を取得します。
	* @return	状態
	*/
	public boolean isConnected();

	/**
	* チェック間隔を設定します。
	* @param	var		設定するデータ
	*/
	public void setCheckInterval( int var );
	/**
	* チェック間隔を取得します。
	* @return	チェック間隔
	*/
	public int getCheckInterval();

	/**
	* 空でも表示するフラグを設定します。
	* @param	var		設定するデータ
	*/
	public void setDisplayOnBlank( boolean var );
	/**
	* 空でも表示するフラグを取得します。
	* @return	空でも表示するフラグ
	*/
	public boolean isDisplayOnBlank();

	/**
	* {@link IChecker}を取得します。
	* @param	name	ICheckerの登録名
	* @return	取得したIChecker
	*/
	public IChecker getChecker( String name ) throws Exception;

	/**
	* {@link IChecker}の一覧を返します。
	* @return	ICheckerの一覧が格納されたMap
	*/
	public Map<String,IChecker> getCheckerMap() throws Exception;

	/**
	* {@link IChecker}を追加します
	* @param	chk		追加するIChecker
	*/
	public void addChecker( IChecker chk ) throws Exception;

	/**
	* {@link IChecker}を削除します。
	* @param	chk		削除するIChecker
	*/
	public void removeChecker( IChecker chk ) throws Exception;

}

