package	jp.co.sds_corp.hibiya.filter;

import jp.co.sds_corp.hibiya.server.CheckerChangeEvent;
import jp.co.sds_corp.hibiya.server.IChecker;
import jp.co.sds_corp.util.config.IConfiguration;

/**
* CheckerChangeEventをフィルタリングます。
*/
public class EventFilter implements IFilter
{
	private static final long serialVersionUID = 1L;
	IChecker.Status	minStatus;	// 最小のステータス
	boolean	unique = true;	// 同一のイベントを排除するか

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		String var;
		var = config.getAttributes().get( "minStatus", "INIT" );
		this.minStatus = IChecker.Status.parse( var );
		var = config.getAttributes().get( "unique", "true" );
		if ( !var.equals( "true" )) {
			this.unique = false;
		}
	}

	/**
	* CheckerChangeEventのがこのフィルタの条件に合致するかを検査します。
	* @param    ev		データ受信イベント
	* @return   イベントのがこのフィルタの条件に合致すればtrue、しなければfalse
	*/
	public boolean match( CheckerChangeEvent ev ) {
		if ( isUnique() && ( ev.getNewStatus() == ev.getOldStatus()) ) {
			return false;
		}
		if ( ev.getNewStatus().compareTo( getMinStatus() ) < 0 ) {
			return false;
		}
		return true;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param    config  親ノード
	*/
	public void saveConfig( IConfiguration config ) {
		config.setAttribute( "class", getClass().getName() );
		config.setAttribute( "minStatus", String.valueOf( getMinStatus()) );
		if ( !isUnique() ) {
			config.setAttribute( "unique", "false" );
		}
	}

	/**
	* 最小のステータスを設定します。
	* @param	var		設定するデータ
	*/
	public void setMinStatus( IChecker.Status var ) {
		this.minStatus = var;
	}
	/**
	* 最小のステータスを取得します。
	* @return	最小のステータス
	*/
	public IChecker.Status getMinStatus() {
		return minStatus;
	}

	/**
	* 同一のイベントを排除するかを設定します。
	* @param	var		設定するデータ
	*/
	public void setUnique( boolean var ) {
		this.unique = var;
	}
	/**
	* 同一のイベントを排除するかを取得します。
	* @return	同一のイベントを排除するか
	*/
	public boolean isUnique() {
		return unique;
	}


}
