package	jp.co.sds_corp.hibiya.server;

import java.util.Date;
import java.util.EventObject;

import jp.co.sds_corp.hibiya.connector.IConnector;

/**
* {@link IChecker}の状態に変化があったことを示すイベントです。
*/
public class CheckerChangeEvent extends EventObject
{
	private static final long serialVersionUID = 1L;
	private Object source;
	private IChecker.Status	nOldStatus = IChecker.Status.INIT;
	private IChecker.Status	nNewStatus = IChecker.Status.INIT;
	private Throwable exc;
	private String message;
	private IConnector connector;
	private Date when;

	/**
	* CheckerChangeEventを生成します。
	* @param	source		イベントの発生元
	* @param	nOldStatus	変更前の状態
	* @param	nNewStatus	変更後の状態
	* @param	exc			発生した例外
	* @param	message		メッセージ
	*/
	public CheckerChangeEvent( Object source,
			IChecker.Status nOldStatus, IChecker.Status nNewStatus,
			Throwable exc, String message )
	{
		this( source, nOldStatus, nNewStatus, exc );
		this.message = message;
		this.when = new Date();
	}

	/**
	* CheckerChangeEventを生成します。
	* @param	source		イベントの発生元
	* @param	nOldStatus	変更前の状態
	* @param	nNewStatus	変更後の状態
	* @param	exc			発生した例外
	*/
	public CheckerChangeEvent( Object source,
			IChecker.Status nOldStatus, IChecker.Status nNewStatus,
			Throwable exc )
	{
		super( source );
		this.source = source;
		this.nOldStatus = nOldStatus;
		this.nNewStatus = nNewStatus;
		this.exc = exc;
		this.when = new Date();
	}

	public Object getSource() {
		if ( source == null ) {
			return super.getSource();
		}
		return source;
	}

	/**
	* 変更前の状態を取得します。
	* @return	変更前の状態
	*/
	public IChecker.Status getOldStatus() {
		return nOldStatus;
	}
	/**
	* 変更後の状態を取得します。
	* @return	変更後の状態
	*/
	public IChecker.Status getNewStatus() {
		return nNewStatus;
	}
	/**
	* 発生した例外を返します。
	* @return	発生した例外
	*/
	public Throwable getException() {
		return exc;
	}
	/**
	* メッセージを返します。
	* @return	メッセージ
	*/
	public String getMessage() {
		return message;
	}
	/**
	* このイベントが発生した時点のタイムスタンプを返します。
	* @return	このイベントが発生した時点のタイムスタンプメッセージ
	*/
	public Date getWhen() {
		return when;
	}

	/**
	* イベントの発生したコネクタ(connector)を設定します。
	* @param	var		設定するデータ
	*/
	public void setConnector( IConnector var ) {
		this.connector = var;
	}
	/**
	* イベントの発生したコネクタ(connector)を取得します。
	* @return	connectorの内容
	*/
	public IConnector getConnector() {
		return connector;
	}

	public String toString() {
		String ret = getClass().getName();
		ret += " source=[" + getSource() + "]";
		ret += " stat=" + nOldStatus + "->" + nNewStatus;
		if ( exc != null ) {
			ret += " exc=" + exc;
		}
		if ( connector != null ) {
			ret += " con=" + connector;
		}
		return ret;
	}
}
