package	jp.co.sds_corp.hibiya.server;

import jp.co.sds_corp.util.common.CmnDate;
import jp.co.sds_corp.util.config.IConfiguration;

/**
プロセスを監視します。
<BR>
XMLは以下の形式です。
<PRE>
&lt;Service name="Proc1" class="jp.co.sds_corp.hibiya.server.ProcessChecker"&gt;
	&lt;Name&gt;processname&lt;/Name&gt;
</PRE>

Action要素については、{@link jp.co.sds_corp.hibiya.action.IAction}
の説明を参照してください。
*/
public class ProcessChecker extends AbstractChecker
{
	private static final long serialVersionUID = 1L;
	int	pid;	// プロセスID
	int	gid;	// グループID
	String	exeName;	// 実行ファイル名

	public ProcessChecker() {
		setType( "Process" );
	}

	/**
	* 設定情報で初期化します。
	* @param	config	設定情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );

		setPid( config.getInteger( "Pid", -1 ));
		setGid( config.getInteger( "Gid", -1 ));
		setExeName( config.get( "ExeName", null ));
	}

	/**
	* 監視処理を実行します。
	*/
	public void check() {
		try {
			CmnDate startTime = new CmnDate();

			CmnDate endTime = new CmnDate();
			clearResult();
			setResponseTime( startTime, endTime );

			setCheckerStatus( IChecker.Status.OK );
		} catch ( Throwable ex ) {
			synchronized( this ) {
				clearResult();
				setException( ex );
				setCheckerStatus( IChecker.Status.NG );
			}
		}
	}

	/**
	* プロセスIDを設定します。
	* @param	var		設定するデータ
	*/
	public void setPid( int var ) {
		this.pid = var;
	}
	/**
	* プロセスIDを取得します。
	* @return	プロセスID
	*/
	public int getPid() {
		return pid;
	}

	/**
	* グループIDを設定します。
	* @param	var		設定するデータ
	*/
	public void setGid( int var ) {
		this.gid = var;
	}
	/**
	* グループIDを取得します。
	* @return	グループID
	*/
	public int getGid() {
		return gid;
	}

	/**
	* 実行ファイル名を設定します。
	* @param	var		設定するデータ
	*/
	public void setExeName( String var ) {
		this.exeName = var;
	}
	/**
	* 実行ファイル名を取得します。
	* @return	実行ファイル名
	*/
	public String getExeName() {
		return exeName;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	設定情報
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
	}

	/**
	* このモニタの文字列表現を返します。
	* @return	このモニタの文字列表現
	*/
	public String toString() {
		String ret = super.toString();
		ret += "["
			+ "PID=" + pid
			+ "GID=" + gid
			+ "EXE=" + exeName
			+ "]";
		return ret;
	}

}
